@@ -31,8 +31,8 @@ message <- function(..., domain = NULL, appendLF = TRUE, .loggit = NA, echo = ge
     tryCatch({
       base::message(..1)
     }, message = function(m) {
-      if (!isFALSE(.loggit)) {
-        loggit(log_lvl = "INFO", log_msg = m[["message"]], echo = echo, ignore_log_level = isTRUE(.loggit))
+      if (isTRUE(.loggit) || (!isFALSE(.loggit) && get_log_level() >= 3L)) {
+        loggit_internal(log_lvl = "INFO", log_msg = conditionMessage(m), echo = echo)
       }
       # If signalCondition was used there would be no output to the console
       base::message(m)
@@ -41,9 +41,9 @@ message <- function(..., domain = NULL, appendLF = TRUE, .loggit = NA, echo = ge
     tryCatch({
       base::message(..., domain = domain, appendLF = appendLF)
     }, message = function(m) {
-      m <- simpleMessage(message = m[["message"]], call = call)
-      if (!isFALSE(.loggit)) {
-        loggit(log_lvl = "INFO", log_msg = m[["message"]], echo = echo, ignore_log_level = isTRUE(.loggit))
+      m <- simpleMessage(message = conditionMessage(m), call = call)
+      if (isTRUE(.loggit) || (!isFALSE(.loggit) && get_log_level() >= 3L)) {
+        loggit_internal(log_lvl = "INFO", log_msg = conditionMessage(m), echo = echo)
       }
       # If signalCondition was used there would be no output to the console
       base::message(m)
@@ -76,25 +76,25 @@ warning <- function(..., call. = TRUE, immediate. = FALSE, noBreaks. = FALSE,
   # If the input is not a condition, the call of the warning must be set manually
   # to avoid loggit2::warning being displayed as a call
   is_condition <- (...length() == 1L && inherits(..1, "condition"))
-  call <- find_call()
+  call <- if (call.) find_call()
 
   if (is_condition) {
     tryCatch({
       base::warning(..1)
     }, warning = function(w) {
-      if (!isFALSE(.loggit)) {
-        loggit(log_lvl = "WARN", log_msg = w[["message"]], echo = echo, ignore_log_level = isTRUE(.loggit))
+      if (isTRUE(.loggit) || (!isFALSE(.loggit) && get_log_level() >= 2L)) {
+        loggit_internal(log_lvl = "WARN", log_msg = conditionMessage(w), echo = echo)
       }
       # If signalCondition was used there would be no output to the console
       base::warning(w)
     })
   } else {
     tryCatch({
-      base::warning(..., call. = call., immediate. = immediate., noBreaks. = noBreaks., domain = domain)
+      base::warning(..., call. = FALSE, immediate. = immediate., noBreaks. = noBreaks., domain = domain)
     }, warning = function(w) {
-      w <- simpleWarning(message = w[["message"]], call = call)
-      if (!isFALSE(.loggit)) {
-        loggit(log_lvl = "WARN", log_msg = w[["message"]], echo = echo, ignore_log_level = isTRUE(.loggit))
+      w <- simpleWarning(message = conditionMessage(w), call = call)
+      if (isTRUE(.loggit) || (!isFALSE(.loggit) && get_log_level() >= 2L)) {
+        loggit_internal(log_lvl = "WARN", log_msg = conditionMessage(w), echo = echo)
       }
       # If signalCondition was used there would be no output to the console
       base::warning(w)
@@ -127,24 +127,24 @@ stop <- function(..., call. = TRUE, domain = NULL, .loggit = NA, echo = get_echo
   # If the input is not a condition, the call of the error must be set manually
   # to avoid loggit2::stop being displayed as a call
   is_condition <- (...length() == 1L && inherits(..1, "condition"))
-  call <- find_call()
+  call <- if (call.) find_call()
 
   if (is_condition) {
     tryCatch({
       base::stop(..1)
     }, error = function(e) {
-      if (!isFALSE(.loggit)) {
-        loggit(log_lvl = "ERROR", log_msg = e[["message"]], echo = echo, ignore_log_level = isTRUE(.loggit))
+      if (isTRUE(.loggit) || (!isFALSE(.loggit) && get_log_level() >= 1L)) {
+        loggit_internal(log_lvl = "ERROR", log_msg = conditionMessage(e), echo = echo)
       }
       base::stop(e)
     })
   } else {
     tryCatch({
-      base::stop(..., call. = call., domain = domain)
+      base::stop(..., call. = FALSE, domain = domain)
     }, error = function(e) {
-      e <- simpleError(message = e[["message"]], call = call)
-      if (!isFALSE(.loggit)) {
-        loggit(log_lvl = "ERROR", log_msg = e[["message"]], echo = echo, ignore_log_level = isTRUE(.loggit))
+      e <- simpleError(message = conditionMessage(e), call = call)
+      if (isTRUE(.loggit) || (!isFALSE(.loggit) && get_log_level() >= 1L)) {
+        loggit_internal(log_lvl = "ERROR", log_msg = conditionMessage(e), echo = echo)
       }
       signalCondition(e)
     })
@@ -194,9 +194,9 @@ stopifnot <- function(..., exprs, exprObject, local, .loggit = NA, echo = get_ec
   tryCatch({
     eval.parent(stop_call, 1L)
   }, error = function(e) {
-    cond <- simpleError(message = e[["message"]], call = call)
-    if (!isFALSE(.loggit)) {
-      loggit(log_lvl = "ERROR", log_msg = cond[["message"]], echo = echo, ignore_log_level = isTRUE(.loggit))
+    cond <- simpleError(message = conditionMessage(e), call = call)
+    if (isTRUE(.loggit) || (!isFALSE(.loggit) && get_log_level() >= 1L)) {
+      loggit_internal(log_lvl = "ERROR", log_msg = conditionMessage(cond), echo = echo)
     }
     signalCondition(cond = cond)
   })
